@@ -1,16 +1,21 @@
 from __future__ import unicode_literals
 
 from django.db import models
-from django.contrib.localflavor.us.models import USStateField
+try:
+    from localflavor.us.models import USStateField
+except ImportError:
+    from django.contrib.localflavor.us.models import USStateField
+
 
 class Group(models.Model):
-    name  = models.CharField(max_length=20)
+    name = models.CharField(max_length=20)
 
     def __unicode__(self):
         return '%s(%d)' % (self.name, self.pk)
 
     __str__ = __unicode__
 
+
 class User(models.Model):
     username = models.CharField(max_length=40)
     group    = models.ForeignKey(Group)
@@ -26,4 +31,3 @@ class User(models.Model):
     time1    = models.TimeField()
     slug     = models.SlugField()
     nullbool = models.NullBooleanField()
-
