@@ -34,6 +34,9 @@ class ValidatorsTest(TestCase):
         self.assertRaises(ValidationError, email(), self.form, DummyField('foo@bar'))
         self.assertRaises(ValidationError, email(), self.form, DummyField('foo@bar.ab12'))
         self.assertRaises(ValidationError, email(), self.form, DummyField('foo@.bar.ab'))
+        self.assertRaises(ValidationError, email(), self.form, DummyField('foo.@bar.co'))
+        self.assertRaises(ValidationError, email(), self.form, DummyField('foo@foo@bar.co'))
+        self.assertRaises(ValidationError, email(), self.form, DummyField('fo o@bar.co'))
 
         # Test IDNA domains
         self.assertEqual(email()(self.form, DummyField(u'foo@bücher.中国')), None)
@@ -78,6 +81,10 @@ class ValidatorsTest(TestCase):
             UUID()(self.form, DummyField('2bc1c94f-0deb-43e9-92a1-4775189ec9f8')),
             None
         )
+        self.assertEqual(
+            UUID()(self.form, DummyField('2bc1c94f0deb43e992a14775189ec9f8')),
+            None
+        )
         self.assertRaises(ValidationError, UUID(), self.form,
                           DummyField('2bc1c94f-deb-43e9-92a1-4775189ec9f8'))
         self.assertRaises(ValidationError, UUID(), self.form,
